==> jc-1.4.0.tar.gz: ppg/util/Item.h <==
// abstract class ppg.util.Item

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5146bf5a25ced51e ppg_util_Item

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_util_Item_H_
#define _JC_ppg_util_Item_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_ppg_util_Item$object;

// Typedefs
typedef struct _jc_ppg_util_Item$sub_refs	_jc_ppg_util_Item$sub_refs;
typedef struct _jc_ppg_util_Item$sub_nonrefs	_jc_ppg_util_Item$sub_nonrefs;
typedef struct _jc_ppg_util_Item$refs	_jc_ppg_util_Item$refs;
typedef struct _jc_ppg_util_Item$nonrefs	_jc_ppg_util_Item$nonrefs;
typedef struct _jc_ppg_util_Item$object	_jc_ppg_util_Item$object;

typedef const struct _jc_ppg_util_Item$vmethods	_jc_ppg_util_Item$vmethods;
typedef const struct _jc_ppg_util_Item$vtable	_jc_ppg_util_Item$vtable;
typedef const struct _jc_ppg_util_Item$vtype	_jc_ppg_util_Item$vtype;

// Constructors
extern void _jc_ppg_util_Item$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_util_Item$object *);

// Virtual methods
extern jint _jc_ppg_util_Item$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_ppg_util_Item$object *, jint, jint, jint, jint, jboolean, jboolean);
extern void _jc_ppg_util_Item$method$free$564111a2cbc836ef(_jc_env *, struct _jc_ppg_util_Item$object *);
extern jint _jc_ppg_util_Item$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_ppg_util_Item$object *, struct _jc_java_io_Writer$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_ppg_util_Item$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_ppg_util_Item$method_info$free$564111a2cbc836ef;
extern _jc_method _jc_ppg_util_Item$method_info$sendOutput$7012ec94d3c70bcd;

// Static methods
extern jint _jc_ppg_util_Item$method$format$8ea040d962cfc63a(_jc_env *, struct _jc_ppg_util_Item$object *, jint, jint, jint, jint, jboolean, jboolean);

// Virtual methods structure
struct _jc_ppg_util_Item$vmethods {
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_ppg_util_Item$object *, jint, jint, jint, jint, jboolean, jboolean);
	void	(*free$564111a2cbc836ef)(_jc_env *, struct _jc_ppg_util_Item$object *);
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_ppg_util_Item$object *, struct _jc_java_io_Writer$object *, jint, jint);
};

// Vtable
struct _jc_ppg_util_Item$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_util_Item$vmethods	ppg_util_Item;
};

// Vtype
struct _jc_ppg_util_Item$vtype {
	_jc_type			type;
	_jc_ppg_util_Item$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_util_Item$sub_refs {
	struct _jc_ppg_util_Item$object	*next;
};

// Reference instance fields (object)
struct _jc_ppg_util_Item$refs {
    _jc_ppg_util_Item$sub_refs	ppg_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_util_Item$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_util_Item$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_util_Item$sub_nonrefs	ppg_util_Item;
};

// Object instance structure
struct _jc_ppg_util_Item$object {
	_jc_ppg_util_Item$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_util_Item$vtype	*vtype;
	_jc_ppg_util_Item$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_util_Item$vtype _jc_ppg_util_Item$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_util_Item, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_util_Item$class_object;

#endif	/* _JC_ppg_util_Item_H_ */

==> jc-1.4.6.tar.gz: ppg/util/Item.h <==
// abstract class ppg.util.Item

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5146bf5a25ced51e ppg_util_Item

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_util_Item_H_
#define _JC_ppg_util_Item_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_ppg_util_Item$object;

// Typedefs
typedef struct _jc_ppg_util_Item$sub_refs	_jc_ppg_util_Item$sub_refs;
typedef struct _jc_ppg_util_Item$sub_nonrefs	_jc_ppg_util_Item$sub_nonrefs;
typedef struct _jc_ppg_util_Item$refs	_jc_ppg_util_Item$refs;
typedef struct _jc_ppg_util_Item$nonrefs	_jc_ppg_util_Item$nonrefs;
typedef struct _jc_ppg_util_Item$object	_jc_ppg_util_Item$object;

typedef const struct _jc_ppg_util_Item$vmethods	_jc_ppg_util_Item$vmethods;
typedef const struct _jc_ppg_util_Item$vtable	_jc_ppg_util_Item$vtable;
typedef const struct _jc_ppg_util_Item$vtype	_jc_ppg_util_Item$vtype;

// Constructors
extern void _jc_ppg_util_Item$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_util_Item$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_ppg_util_Item$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_ppg_util_Item$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
extern void _jc_ppg_util_Item$method$free$564111a2cbc836ef(_jc_env *, struct _jc_ppg_util_Item$object *) _JC_JCNI_ATTR;
extern jint _jc_ppg_util_Item$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_ppg_util_Item$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_util_Item$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_ppg_util_Item$method_info$free$564111a2cbc836ef;
extern _jc_method _jc_ppg_util_Item$method_info$sendOutput$7012ec94d3c70bcd;

// Static methods
extern jint _jc_ppg_util_Item$method$format$8ea040d962cfc63a(_jc_env *, struct _jc_ppg_util_Item$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_ppg_util_Item$vmethods {
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_ppg_util_Item$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
	void	(*free$564111a2cbc836ef)(_jc_env *, struct _jc_ppg_util_Item$object *) _JC_JCNI_ATTR;
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_ppg_util_Item$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_util_Item$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_util_Item$vmethods	ppg_util_Item;
};

// Vtype
struct _jc_ppg_util_Item$vtype {
	_jc_type			type;
	_jc_ppg_util_Item$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_util_Item$sub_refs {
	struct _jc_ppg_util_Item$object	*next;
};

// Reference instance fields (object)
struct _jc_ppg_util_Item$refs {
    _jc_ppg_util_Item$sub_refs	ppg_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_util_Item$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_util_Item$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_util_Item$sub_nonrefs	ppg_util_Item;
};

// Object instance structure
struct _jc_ppg_util_Item$object {
	_jc_ppg_util_Item$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_util_Item$vtype	*vtype;
	_jc_ppg_util_Item$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_util_Item$vtype _jc_ppg_util_Item$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_util_Item, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_util_Item$class_object;

#endif	/* _JC_ppg_util_Item_H_ */
